/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 * 
 *       http://www.apache.org/licenses/LICENSE-2.0
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.apache.geronimo.samples.bank.ejb;

import javax.ejb.EntityBean;

/**
 * 
 * @ejb.bean type="CMP" cmp-version="2.x" name="Account"
 *           local-jndi-name="java:comp/env/ejb/Account" view-type="local"
 *           primkey-field="accountNumber"
 * 
 * @ejb.interface generate="local"
 *                local-class="org.apache.geronimo.samples.bank.ejb.AccountLocal"
 * @ejb.home generate="local"
 *           local-class="org.apache.geronimo.samples.bank.ejb.AccountHomeLocal"
 * 
 * @web.ejb-local-ref name="ejb/Account" type="Entity"
 *                    home="org.apache.geronimo.samples.bank.ejb.AccountHomeLocal"
 *                    local="org.apache.geronimo.samples.bank.ejb.AccountLocal"
 *                    link="Account"
 * 
 * @ejb.persistence table-name="account"
 * 
 * 
 */

public abstract class AccountBean implements EntityBean {

	/**
	 * @ejb.pk-field
	 * @ejb.persistence column-name="ACC_NO"
	 * @ejb.interface-method view-type="local"
	 * @return
	 */
	public abstract String getAccountNumber();

	/**
	 * @ejb.interface-method view-type="local"
	 * @param newValue
	 */
	public abstract void setAccountNumber(String accNo);
	
	/**
	 * @ejb.persistence column-name="ACC_TYPE"
	 * @ejb.interface-method view-type="local"
	 * @return
	 */
	public abstract String getAccountType();
	
	
	/**
	 * @ejb.interface-method view-type="local"
	 * @param accType
	 */
	public abstract void setAccountType(String accType);
	
	/**
	 * @ejb.persistence column-name="BALANCE"
	 * @ejb.interface-method view-type="local"
	 * @return
	 */
	public abstract Double getBalance();
	
	/**
	 * @ejb.interface-method view-type="local"
	 * @param balance
	 */
	public abstract void setBalance(Double balance);
	
 

	/**
	 * @ejb.relation name = "Customer-Account" target-ejb = "Customer"
	 * 					target-role-name = "Customer-to-Account"
	 * 					role-name = "Account-to-Customer" target-multiple = "yes"
	 * @ejb.persistence column-name="CUSTID_FK"
	 * @ejb.interface-method view-type="local"
	 * @return
	 */
	public abstract CustomerLocal getCustomer();
	
	/**
	 * @ejb.interface-method view-type="local"
	 * @param customer
	 */
	public abstract void setCustomer(CustomerLocal customer);

	/**
	 * @ejb.create-method
	 */
	public java.lang.String ejbCreate() throws javax.ejb.CreateException {
		return null;
	}

	public void ejbPostCreate() throws javax.ejb.CreateException {
	}

}
